"extrap.bands" = function(x, subset = T, dbh = lba.dend.dbhs.filled[,"DOYsince1999.196"], 
	fam = dend.tree.info$family, Ni = dend.tree.info$Ni, 
	Ai = dend.tree.info$Ai, brk = c(9., 22.49, 34.99,54.99, 89.99, 200.))
{
	# function 'extrap.bands' extrapolates a statistic from banded trees to plots
	# started:  6/8/00 by srs
	#
	# requires:  
	# x = a vector, length = nrow(lba.dend.dbhs.filled.dbhs)=993 (the orginal n of banded 
	#	trees) of variable of interest 
	#	(note:  needs to be orginal length to do proper match-up of categories)
	# dbh = the original dbh of each tree (the basis on which it was assigned to a category)
	# fam = the taxonomic family to which it belongs (original set)
	# brk = boundaries of the size-classes used to for original sample categories
	# Ni  = total number of trees in each category of the original full sample 
	# Ai  = total area sampled for each category of the full sample (either 19.75 ha or 3.99 ha)
	#
	#   (default operations requires access to lba.dend.dbhs.filled variables: dbh.7.99, family, Ni, Ai)
	#
	# optional:
	# subset = logical vector as long as var selecting a subset of data
	#        (the number in each category of the subset is used to create Bi, and the inflation factor)
	#
	# The extrapolation works like this.  Let:
	#   Ni = total number of tagged trees  in family-size category i
	#   Ai = area sampled for ith category (either 19.75 ha for large, or 4.99 ha for small)
	#      (note:  the above two are fixed by the original sample design)
	#   Bi = number of banded trees (sub-sample) in the ith category
	# Then:
	#   Di = number density of trees in ith category = Ni/Ai (#/ha)
	#   Dt = total number density across all categories = sum(Di) (#/ha)
	#   X.bar = mean of some measurement X (e.g. tree height) = 1/Dt * sum( Di * Xi.bar )
	#        where Xi.bar = mean of X across all trees in ith category = 1/Bi sum(Xi)
	#   X.sum.area = sum total per area of some X (e.g. biomass) = sum( Di * Xi.bar)
	# (i.e., individual measurements in each category need to be inflated by a factor:  Ni/(Ai Bi) )
	#  
	# table:  gives number (Bi) in each family-size category, i
	Bi. <- table(fam[subset], cut(dbh[subset], brk))
	#  (i.Bi points from each tree in subset to the number of trees that are in that trees category
	i.Bi <- tapply(x[subset], list(fam[subset], cut(dbh[subset], brk)))
	# index (as long as subset)
	# vector (length of subset) of Bi
	Bi <- Bi.[i.Bi]
	Di <- (Ni/Ai)[subset]
	# * (Ni[subset]/Bi)
	xi <- x[subset]
	x.sum <- sum((Di * xi)/Bi)
	Di.t <- tapply(Di, list(fam[subset], cut(dbh[subset], brk)), function(x)
	x[1.])
	# Dt <- 460 # best estimate of overall tree density at this site
	Dt <- sum(Di.t, na.rm = T)
	# x.sum.per.ha <- sum((x.wt/Ai[subset]) )
	# x.mean.ha.wt _ x.sum.per.ha/sum((Ni/Ai)[subset])
	# x.mean.per.ha <- x.sum.per.ha/length(x[subset])
	x.mean <- x.sum/Dt
	# , mean.ha.wt= x.mean.ha.wt, sum.per.ha = x.sum.per.ha, mean.per.ha = x.bar.area)
	c(sum = x.sum, mean = x.mean)
}
